@@ -65,7 +65,7 @@ class Bitbucket():
                 if val['created_on'] < created_on_not_later:
                     print('Stopping on (1 hour diff): {}: {}'.format(val['build_number'], val['created_on']))
                     return result
-                if val['build_number'] > number:
+                if val['build_number'] > int(number):
                     print('Skipping (number higher): {}: {}'.format(val['build_number'], val['created_on']))
                     continue
 
@@ -89,7 +89,7 @@ class Bitbucket():
                 return result
 
             for val in resp['values']:
-                if val['build_number'] < number:
+                if val['build_number'] < int(number):
                     print('Stopping on (number lower): {}: {}'.format(val['build_number'], val['created_on']))
                     return result
 
@@ -116,8 +116,8 @@ class Bitbucket():
             repo_name=os.environ.get('BITBUCKET_REPO_SLUG'),
             url=url
         ),
-            headers={'Authorization': 'JWT {jwt_token}'.format(jwt_token=os.environ.get('PIPELINES_JWT_TOKEN'))},
-            # auth=HTTPBasicAuth(os.environ.get('BITBUCKET_USERNAME'), os.environ.get('BITBUCKET_PASSWORD'))
+            headers={'Content-Type': 'application/json'},
+            auth=HTTPBasicAuth(os.environ.get('BITBUCKET_USERNAME'), os.environ.get('BITBUCKET_PASSWORD'))
         )
 
         if resp.status_code >= 400:
@@ -134,8 +134,8 @@ class Bitbucket():
             repo_name=os.environ.get('BITBUCKET_REPO_SLUG'),
             url=url
         ),
-            headers={'Authorization': 'JWT {jwt_token}'.format(jwt_token=os.environ.get('PIPELINES_JWT_TOKEN'))},
-            # auth=HTTPBasicAuth(os.environ.get('BITBUCKET_USERNAME'), os.environ.get('BITBUCKET_PASSWORD'))
+            headers={'Content-Type': 'application/json'},
+            auth=HTTPBasicAuth(os.environ.get('BITBUCKET_USERNAME'), os.environ.get('BITBUCKET_PASSWORD'))
         )
 
         if resp.status_code >= 400:
